import * as express from 'express';
import { HttpsFunction, Runnable } from '../cloud-functions';
import { ManifestEndpoint, ManifestRequiredAPI } from '../common/manifest';
import { CallableContext, FunctionsErrorCode, HttpsError, Request, TaskContext, TaskRateLimits, TaskRetryConfig } from '../common/providers/https';
import { DeploymentOptions } from '../function-configuration';
export { Request, CallableContext, FunctionsErrorCode, HttpsError, 
/** @hidden */
TaskRetryConfig as TaskRetryPolicy, 
/** @hidden */
TaskRateLimits, 
/** @hidden */
TaskContext, };
/**
 * Handle HTTP requests.
 * @param handler A function that takes a request and response object,
 * same signature as an Express app.
 */
export declare function onRequest(handler: (req: Request, resp: express.Response) => void | Promise<void>): HttpsFunction;
/**
 * Declares a callable method for clients to call using a Firebase SDK.
 * @param handler A method that takes a data and context and returns a value.
 */
export declare function onCall(handler: (data: any, context: CallableContext) => any | Promise<any>): HttpsFunction & Runnable<any>;
/**
 * Configurations for Task Queue Functions.
 * @hidden
 */
export interface TaskQueueOptions {
    retryConfig?: TaskRetryConfig;
    rateLimits?: TaskRateLimits;
    /**
     * Who can enqueue tasks for this function.
     * If left unspecified, only service accounts which have
     * roles/cloudtasks.enqueuer and roles/cloudfunctions.invoker
     * will have permissions.
     */
    invoker?: 'private' | string | string[];
}
/** @hidden */
export interface TaskQueueFunction {
    (req: Request, res: express.Response): Promise<void>;
    __trigger: unknown;
    __endpoint: ManifestEndpoint;
    __requiredAPIs?: ManifestRequiredAPI[];
    run(data: any, context: TaskContext): void | Promise<void>;
}
/** @hidden */
export declare class TaskQueueBuilder {
    private readonly tqOpts?;
    private readonly depOpts?;
    onDispatch(handler: (data: any, context: TaskContext) => void | Promise<void>): TaskQueueFunction;
}
/**
 * Declares a function that can handle tasks enqueued using the Firebase Admin SDK.
 * @param options Configuration for the Task Queue that feeds into this function.
 * @hidden
 */
export declare function taskQueue(options?: TaskQueueOptions): TaskQueueBuilder;
/** @hidden */
export declare function _onRequestWithOptions(handler: (req: Request, resp: express.Response) => void | Promise<void>, options: DeploymentOptions): HttpsFunction;
/** @hidden */
export declare function _onCallWithOptions(handler: (data: any, context: CallableContext) => any | Promise<any>, options: DeploymentOptions): HttpsFunction & Runnable<any>;
